@@ -2,6 +2,6 @@
 
 from readimc.data._slide import Slide
 from readimc.data._panorama import Panorama
-from readimc.data._acquisition import Acquisition
+from readimc.data._acquisition import Acquisition, AcquisitionBase
 
-__all__ = ["Slide", "Panorama", "Acquisition"]
+__all__ = ["Slide", "Panorama", "Acquisition", "AcquisitionBase"]
